Documentation
¶
Index ¶
- Constants
- Variables
- func DeaggreateRecords(in []*kinesis.Record) ([]*kinesis.Record, error)
- type AdditionalDimension
- func (*AdditionalDimension) Descriptor() ([]byte, []int)
- func (m *AdditionalDimension) GetGranularity() string
- func (m *AdditionalDimension) GetKey() string
- func (m *AdditionalDimension) GetValue() string
- func (*AdditionalDimension) ProtoMessage()
- func (m *AdditionalDimension) Reset()
- func (m *AdditionalDimension) String() string
- func (m *AdditionalDimension) XXX_DiscardUnknown()
- func (m *AdditionalDimension) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *AdditionalDimension) XXX_Merge(src proto.Message)
- func (m *AdditionalDimension) XXX_Size() int
- func (m *AdditionalDimension) XXX_Unmarshal(b []byte) error
- type AggregatedRecord
- func (*AggregatedRecord) Descriptor() ([]byte, []int)
- func (m *AggregatedRecord) GetExplicitHashKeyTable() []string
- func (m *AggregatedRecord) GetPartitionKeyTable() []string
- func (m *AggregatedRecord) GetRecords() []*Record
- func (*AggregatedRecord) ProtoMessage()
- func (m *AggregatedRecord) Reset()
- func (m *AggregatedRecord) String() string
- func (m *AggregatedRecord) XXX_DiscardUnknown()
- func (m *AggregatedRecord) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *AggregatedRecord) XXX_Merge(src proto.Message)
- func (m *AggregatedRecord) XXX_Size() int
- func (m *AggregatedRecord) XXX_Unmarshal(b []byte) error
- type Attempt
- func (*Attempt) Descriptor() ([]byte, []int)
- func (m *Attempt) GetDelay() uint32
- func (m *Attempt) GetDuration() uint32
- func (m *Attempt) GetErrorCode() string
- func (m *Attempt) GetErrorMessage() string
- func (m *Attempt) GetSuccess() bool
- func (*Attempt) ProtoMessage()
- func (m *Attempt) Reset()
- func (m *Attempt) String() string
- func (m *Attempt) XXX_DiscardUnknown()
- func (m *Attempt) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Attempt) XXX_Merge(src proto.Message)
- func (m *Attempt) XXX_Size() int
- func (m *Attempt) XXX_Unmarshal(b []byte) error
- type Configuration
- func (*Configuration) Descriptor() ([]byte, []int)
- func (m *Configuration) GetAdditionalMetricDims() []*AdditionalDimension
- func (m *Configuration) GetAggregationEnabled() bool
- func (m *Configuration) GetAggregationMaxCount() uint64
- func (m *Configuration) GetAggregationMaxSize() uint64
- func (m *Configuration) GetCloudwatchEndpoint() string
- func (m *Configuration) GetCloudwatchPort() uint64
- func (m *Configuration) GetCollectionMaxCount() uint64
- func (m *Configuration) GetCollectionMaxSize() uint64
- func (m *Configuration) GetConnectTimeout() uint64
- func (m *Configuration) GetEnableCoreDumps() bool
- func (m *Configuration) GetFailIfThrottled() bool
- func (m *Configuration) GetKinesisEndpoint() string
- func (m *Configuration) GetKinesisPort() uint64
- func (m *Configuration) GetLogLevel() string
- func (m *Configuration) GetMaxConnections() uint64
- func (m *Configuration) GetMetricsGranularity() string
- func (m *Configuration) GetMetricsLevel() string
- func (m *Configuration) GetMetricsNamespace() string
- func (m *Configuration) GetMetricsUploadDelay() uint64
- func (m *Configuration) GetMinConnections() uint64
- func (m *Configuration) GetRateLimit() uint64
- func (m *Configuration) GetRecordMaxBufferedTime() uint64
- func (m *Configuration) GetRecordTtl() uint64
- func (m *Configuration) GetRegion() string
- func (m *Configuration) GetRequestTimeout() uint64
- func (m *Configuration) GetThreadConfig() Configuration_ThreadConfig
- func (m *Configuration) GetThreadPoolSize() uint32
- func (m *Configuration) GetVerifyCertificate() bool
- func (*Configuration) ProtoMessage()
- func (m *Configuration) Reset()
- func (m *Configuration) String() string
- func (m *Configuration) XXX_DiscardUnknown()
- func (m *Configuration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Configuration) XXX_Merge(src proto.Message)
- func (m *Configuration) XXX_Size() int
- func (m *Configuration) XXX_Unmarshal(b []byte) error
- type Configuration_ThreadConfig
- type Credentials
- func (*Credentials) Descriptor() ([]byte, []int)
- func (m *Credentials) GetAkid() string
- func (m *Credentials) GetSecretKey() string
- func (m *Credentials) GetToken() string
- func (*Credentials) ProtoMessage()
- func (m *Credentials) Reset()
- func (m *Credentials) String() string
- func (m *Credentials) XXX_DiscardUnknown()
- func (m *Credentials) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Credentials) XXX_Merge(src proto.Message)
- func (m *Credentials) XXX_Size() int
- func (m *Credentials) XXX_Unmarshal(b []byte) error
- type Dimension
- func (*Dimension) Descriptor() ([]byte, []int)
- func (m *Dimension) GetKey() string
- func (m *Dimension) GetValue() string
- func (*Dimension) ProtoMessage()
- func (m *Dimension) Reset()
- func (m *Dimension) String() string
- func (m *Dimension) XXX_DiscardUnknown()
- func (m *Dimension) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Dimension) XXX_Merge(src proto.Message)
- func (m *Dimension) XXX_Size() int
- func (m *Dimension) XXX_Unmarshal(b []byte) error
- type Flush
- func (*Flush) Descriptor() ([]byte, []int)
- func (m *Flush) GetStreamName() string
- func (*Flush) ProtoMessage()
- func (m *Flush) Reset()
- func (m *Flush) String() string
- func (m *Flush) XXX_DiscardUnknown()
- func (m *Flush) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Flush) XXX_Merge(src proto.Message)
- func (m *Flush) XXX_Size() int
- func (m *Flush) XXX_Unmarshal(b []byte) error
- type Message
- func (*Message) Descriptor() ([]byte, []int)
- func (m *Message) GetActualMessage() isMessage_ActualMessage
- func (m *Message) GetConfiguration() *Configuration
- func (m *Message) GetFlush() *Flush
- func (m *Message) GetId() uint64
- func (m *Message) GetMetricsRequest() *MetricsRequest
- func (m *Message) GetMetricsResponse() *MetricsResponse
- func (m *Message) GetPutRecord() *PutRecord
- func (m *Message) GetPutRecordResult() *PutRecordResult
- func (m *Message) GetSetCredentials() *SetCredentials
- func (m *Message) GetSourceId() uint64
- func (*Message) ProtoMessage()
- func (m *Message) Reset()
- func (m *Message) String() string
- func (m *Message) XXX_DiscardUnknown()
- func (m *Message) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Message) XXX_Merge(src proto.Message)
- func (*Message) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, ...)
- func (m *Message) XXX_Size() int
- func (m *Message) XXX_Unmarshal(b []byte) error
- type Message_Configuration
- type Message_Flush
- type Message_MetricsRequest
- type Message_MetricsResponse
- type Message_PutRecord
- type Message_PutRecordResult
- type Message_SetCredentials
- type Metric
- func (*Metric) Descriptor() ([]byte, []int)
- func (m *Metric) GetDimensions() []*Dimension
- func (m *Metric) GetName() string
- func (m *Metric) GetSeconds() uint64
- func (m *Metric) GetStats() *Stats
- func (*Metric) ProtoMessage()
- func (m *Metric) Reset()
- func (m *Metric) String() string
- func (m *Metric) XXX_DiscardUnknown()
- func (m *Metric) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Metric) XXX_Merge(src proto.Message)
- func (m *Metric) XXX_Size() int
- func (m *Metric) XXX_Unmarshal(b []byte) error
- type MetricsRequest
- func (*MetricsRequest) Descriptor() ([]byte, []int)
- func (m *MetricsRequest) GetName() string
- func (m *MetricsRequest) GetSeconds() uint64
- func (*MetricsRequest) ProtoMessage()
- func (m *MetricsRequest) Reset()
- func (m *MetricsRequest) String() string
- func (m *MetricsRequest) XXX_DiscardUnknown()
- func (m *MetricsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *MetricsRequest) XXX_Merge(src proto.Message)
- func (m *MetricsRequest) XXX_Size() int
- func (m *MetricsRequest) XXX_Unmarshal(b []byte) error
- type MetricsResponse
- func (*MetricsResponse) Descriptor() ([]byte, []int)
- func (m *MetricsResponse) GetMetrics() []*Metric
- func (*MetricsResponse) ProtoMessage()
- func (m *MetricsResponse) Reset()
- func (m *MetricsResponse) String() string
- func (m *MetricsResponse) XXX_DiscardUnknown()
- func (m *MetricsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *MetricsResponse) XXX_Merge(src proto.Message)
- func (m *MetricsResponse) XXX_Size() int
- func (m *MetricsResponse) XXX_Unmarshal(b []byte) error
- type PutRecord
- func (*PutRecord) Descriptor() ([]byte, []int)
- func (m *PutRecord) GetData() []byte
- func (m *PutRecord) GetExplicitHashKey() string
- func (m *PutRecord) GetPartitionKey() string
- func (m *PutRecord) GetStreamName() string
- func (*PutRecord) ProtoMessage()
- func (m *PutRecord) Reset()
- func (m *PutRecord) String() string
- func (m *PutRecord) XXX_DiscardUnknown()
- func (m *PutRecord) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *PutRecord) XXX_Merge(src proto.Message)
- func (m *PutRecord) XXX_Size() int
- func (m *PutRecord) XXX_Unmarshal(b []byte) error
- type PutRecordResult
- func (*PutRecordResult) Descriptor() ([]byte, []int)
- func (m *PutRecordResult) GetAttempts() []*Attempt
- func (m *PutRecordResult) GetSequenceNumber() string
- func (m *PutRecordResult) GetShardId() string
- func (m *PutRecordResult) GetSuccess() bool
- func (*PutRecordResult) ProtoMessage()
- func (m *PutRecordResult) Reset()
- func (m *PutRecordResult) String() string
- func (m *PutRecordResult) XXX_DiscardUnknown()
- func (m *PutRecordResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *PutRecordResult) XXX_Merge(src proto.Message)
- func (m *PutRecordResult) XXX_Size() int
- func (m *PutRecordResult) XXX_Unmarshal(b []byte) error
- type Record
- func (*Record) Descriptor() ([]byte, []int)
- func (m *Record) GetData() []byte
- func (m *Record) GetExplicitHashKeyIndex() uint64
- func (m *Record) GetPartitionKeyIndex() uint64
- func (m *Record) GetTags() []*Tag
- func (*Record) ProtoMessage()
- func (m *Record) Reset()
- func (m *Record) String() string
- func (m *Record) XXX_DiscardUnknown()
- func (m *Record) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Record) XXX_Merge(src proto.Message)
- func (m *Record) XXX_Size() int
- func (m *Record) XXX_Unmarshal(b []byte) error
- type SetCredentials
- func (*SetCredentials) Descriptor() ([]byte, []int)
- func (m *SetCredentials) GetCredentials() *Credentials
- func (m *SetCredentials) GetForMetrics() bool
- func (*SetCredentials) ProtoMessage()
- func (m *SetCredentials) Reset()
- func (m *SetCredentials) String() string
- func (m *SetCredentials) XXX_DiscardUnknown()
- func (m *SetCredentials) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *SetCredentials) XXX_Merge(src proto.Message)
- func (m *SetCredentials) XXX_Size() int
- func (m *SetCredentials) XXX_Unmarshal(b []byte) error
- type Stats
- func (*Stats) Descriptor() ([]byte, []int)
- func (m *Stats) GetCount() float64
- func (m *Stats) GetMax() float64
- func (m *Stats) GetMean() float64
- func (m *Stats) GetMin() float64
- func (m *Stats) GetSum() float64
- func (*Stats) ProtoMessage()
- func (m *Stats) Reset()
- func (m *Stats) String() string
- func (m *Stats) XXX_DiscardUnknown()
- func (m *Stats) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Stats) XXX_Merge(src proto.Message)
- func (m *Stats) XXX_Size() int
- func (m *Stats) XXX_Unmarshal(b []byte) error
- type Tag
- func (*Tag) Descriptor() ([]byte, []int)
- func (m *Tag) GetKey() string
- func (m *Tag) GetValue() string
- func (*Tag) ProtoMessage()
- func (m *Tag) Reset()
- func (m *Tag) String() string
- func (m *Tag) XXX_DiscardUnknown()
- func (m *Tag) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Tag) XXX_Merge(src proto.Message)
- func (m *Tag) XXX_Size() int
- func (m *Tag) XXX_Unmarshal(b []byte) error
Constants ¶
const Default_Configuration_AggregationEnabled bool = true
const Default_Configuration_AggregationMaxCount uint64 = 4294967295
const Default_Configuration_AggregationMaxSize uint64 = 51200
const Default_Configuration_CloudwatchPort uint64 = 443
const Default_Configuration_CollectionMaxCount uint64 = 500
const Default_Configuration_CollectionMaxSize uint64 = 5242880
const Default_Configuration_ConnectTimeout uint64 = 6000
const Default_Configuration_EnableCoreDumps bool = false
const Default_Configuration_FailIfThrottled bool = false
const Default_Configuration_KinesisPort uint64 = 443
const Default_Configuration_LogLevel string = "info"
const Default_Configuration_MaxConnections uint64 = 24
const Default_Configuration_MetricsGranularity string = "shard"
const Default_Configuration_MetricsLevel string = "detailed"
const Default_Configuration_MetricsNamespace string = "KinesisProducerLibrary"
const Default_Configuration_MetricsUploadDelay uint64 = 60000
const Default_Configuration_MinConnections uint64 = 1
const Default_Configuration_RateLimit uint64 = 150
const Default_Configuration_RecordMaxBufferedTime uint64 = 100
const Default_Configuration_RecordTtl uint64 = 30000
const Default_Configuration_RequestTimeout uint64 = 6000
const Default_Configuration_ThreadPoolSize uint32 = 64
const Default_Configuration_VerifyCertificate bool = true
Variables ¶
var Configuration_ThreadConfig_name = map[int32]string{
0: "PER_REQUEST",
1: "POOLED",
}
var Configuration_ThreadConfig_value = map[string]int32{
"PER_REQUEST": 0,
"POOLED": 1,
}
var (
MagicHeader = []byte{0xF3, 0x89, 0x9A, 0xC2}
)
refs: https://github.com/awslabs/amazon-kinesis-producer/blob/master/aggregation-format.md
Functions ¶
Types ¶
type AdditionalDimension ¶
type AdditionalDimension struct {
Key *string `protobuf:"bytes,1,req,name=key" json:"key,omitempty"`
Value *string `protobuf:"bytes,2,req,name=value" json:"value,omitempty"`
Granularity *string `protobuf:"bytes,3,req,name=granularity" json:"granularity,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AdditionalDimension) Descriptor ¶
func (*AdditionalDimension) Descriptor() ([]byte, []int)
func (*AdditionalDimension) GetGranularity ¶
func (m *AdditionalDimension) GetGranularity() string
func (*AdditionalDimension) GetKey ¶
func (m *AdditionalDimension) GetKey() string
func (*AdditionalDimension) GetValue ¶
func (m *AdditionalDimension) GetValue() string
func (*AdditionalDimension) ProtoMessage ¶
func (*AdditionalDimension) ProtoMessage()
func (*AdditionalDimension) Reset ¶
func (m *AdditionalDimension) Reset()
func (*AdditionalDimension) String ¶
func (m *AdditionalDimension) String() string
func (*AdditionalDimension) XXX_DiscardUnknown ¶
func (m *AdditionalDimension) XXX_DiscardUnknown()
func (*AdditionalDimension) XXX_Marshal ¶
func (m *AdditionalDimension) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AdditionalDimension) XXX_Merge ¶
func (dst *AdditionalDimension) XXX_Merge(src proto.Message)
func (*AdditionalDimension) XXX_Size ¶
func (m *AdditionalDimension) XXX_Size() int
func (*AdditionalDimension) XXX_Unmarshal ¶
func (m *AdditionalDimension) XXX_Unmarshal(b []byte) error
type AggregatedRecord ¶
type AggregatedRecord struct {
PartitionKeyTable []string `protobuf:"bytes,1,rep,name=partition_key_table,json=partitionKeyTable" json:"partition_key_table,omitempty"`
ExplicitHashKeyTable []string `protobuf:"bytes,2,rep,name=explicit_hash_key_table,json=explicitHashKeyTable" json:"explicit_hash_key_table,omitempty"`
Records []*Record `protobuf:"bytes,3,rep,name=records" json:"records,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AggregatedRecord) Descriptor ¶
func (*AggregatedRecord) Descriptor() ([]byte, []int)
func (*AggregatedRecord) GetExplicitHashKeyTable ¶
func (m *AggregatedRecord) GetExplicitHashKeyTable() []string
func (*AggregatedRecord) GetPartitionKeyTable ¶
func (m *AggregatedRecord) GetPartitionKeyTable() []string
func (*AggregatedRecord) GetRecords ¶
func (m *AggregatedRecord) GetRecords() []*Record
func (*AggregatedRecord) ProtoMessage ¶
func (*AggregatedRecord) ProtoMessage()
func (*AggregatedRecord) Reset ¶
func (m *AggregatedRecord) Reset()
func (*AggregatedRecord) String ¶
func (m *AggregatedRecord) String() string
func (*AggregatedRecord) XXX_DiscardUnknown ¶
func (m *AggregatedRecord) XXX_DiscardUnknown()
func (*AggregatedRecord) XXX_Marshal ¶
func (m *AggregatedRecord) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AggregatedRecord) XXX_Merge ¶
func (dst *AggregatedRecord) XXX_Merge(src proto.Message)
func (*AggregatedRecord) XXX_Size ¶
func (m *AggregatedRecord) XXX_Size() int
func (*AggregatedRecord) XXX_Unmarshal ¶
func (m *AggregatedRecord) XXX_Unmarshal(b []byte) error
type Attempt ¶
type Attempt struct {
Delay *uint32 `protobuf:"varint,1,req,name=delay" json:"delay,omitempty"`
Duration *uint32 `protobuf:"varint,2,req,name=duration" json:"duration,omitempty"`
Success *bool `protobuf:"varint,3,req,name=success" json:"success,omitempty"`
ErrorCode *string `protobuf:"bytes,4,opt,name=error_code,json=errorCode" json:"error_code,omitempty"`
ErrorMessage *string `protobuf:"bytes,5,opt,name=error_message,json=errorMessage" json:"error_message,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Attempt) Descriptor ¶
func (*Attempt) GetDuration ¶
func (*Attempt) GetErrorCode ¶
func (*Attempt) GetErrorMessage ¶
func (*Attempt) GetSuccess ¶
func (*Attempt) ProtoMessage ¶
func (*Attempt) ProtoMessage()
func (*Attempt) XXX_DiscardUnknown ¶
func (m *Attempt) XXX_DiscardUnknown()
func (*Attempt) XXX_Marshal ¶
func (*Attempt) XXX_Unmarshal ¶
type Configuration ¶
type Configuration struct {
AdditionalMetricDims []*AdditionalDimension `protobuf:"bytes,128,rep,name=additional_metric_dims,json=additionalMetricDims" json:"additional_metric_dims,omitempty"`
AggregationEnabled *bool `protobuf:"varint,1,opt,name=aggregation_enabled,json=aggregationEnabled,def=1" json:"aggregation_enabled,omitempty"`
AggregationMaxCount *uint64 `` /* 129-byte string literal not displayed */
AggregationMaxSize *uint64 `protobuf:"varint,3,opt,name=aggregation_max_size,json=aggregationMaxSize,def=51200" json:"aggregation_max_size,omitempty"`
CloudwatchEndpoint *string `protobuf:"bytes,4,opt,name=cloudwatch_endpoint,json=cloudwatchEndpoint,def=" json:"cloudwatch_endpoint,omitempty"`
CloudwatchPort *uint64 `protobuf:"varint,5,opt,name=cloudwatch_port,json=cloudwatchPort,def=443" json:"cloudwatch_port,omitempty"`
CollectionMaxCount *uint64 `protobuf:"varint,6,opt,name=collection_max_count,json=collectionMaxCount,def=500" json:"collection_max_count,omitempty"`
CollectionMaxSize *uint64 `protobuf:"varint,7,opt,name=collection_max_size,json=collectionMaxSize,def=5242880" json:"collection_max_size,omitempty"`
ConnectTimeout *uint64 `protobuf:"varint,8,opt,name=connect_timeout,json=connectTimeout,def=6000" json:"connect_timeout,omitempty"`
EnableCoreDumps *bool `protobuf:"varint,9,opt,name=enable_core_dumps,json=enableCoreDumps,def=0" json:"enable_core_dumps,omitempty"`
FailIfThrottled *bool `protobuf:"varint,10,opt,name=fail_if_throttled,json=failIfThrottled,def=0" json:"fail_if_throttled,omitempty"`
KinesisEndpoint *string `protobuf:"bytes,11,opt,name=kinesis_endpoint,json=kinesisEndpoint,def=" json:"kinesis_endpoint,omitempty"`
KinesisPort *uint64 `protobuf:"varint,12,opt,name=kinesis_port,json=kinesisPort,def=443" json:"kinesis_port,omitempty"`
LogLevel *string `protobuf:"bytes,13,opt,name=log_level,json=logLevel,def=info" json:"log_level,omitempty"`
MaxConnections *uint64 `protobuf:"varint,14,opt,name=max_connections,json=maxConnections,def=24" json:"max_connections,omitempty"`
MetricsGranularity *string `protobuf:"bytes,15,opt,name=metrics_granularity,json=metricsGranularity,def=shard" json:"metrics_granularity,omitempty"`
MetricsLevel *string `protobuf:"bytes,16,opt,name=metrics_level,json=metricsLevel,def=detailed" json:"metrics_level,omitempty"`
MetricsNamespace *string `` /* 130-byte string literal not displayed */
MetricsUploadDelay *uint64 `protobuf:"varint,18,opt,name=metrics_upload_delay,json=metricsUploadDelay,def=60000" json:"metrics_upload_delay,omitempty"`
MinConnections *uint64 `protobuf:"varint,19,opt,name=min_connections,json=minConnections,def=1" json:"min_connections,omitempty"`
RateLimit *uint64 `protobuf:"varint,20,opt,name=rate_limit,json=rateLimit,def=150" json:"rate_limit,omitempty"`
RecordMaxBufferedTime *uint64 `` /* 131-byte string literal not displayed */
RecordTtl *uint64 `protobuf:"varint,22,opt,name=record_ttl,json=recordTtl,def=30000" json:"record_ttl,omitempty"`
Region *string `protobuf:"bytes,23,opt,name=region,def=" json:"region,omitempty"`
RequestTimeout *uint64 `protobuf:"varint,24,opt,name=request_timeout,json=requestTimeout,def=6000" json:"request_timeout,omitempty"`
VerifyCertificate *bool `protobuf:"varint,25,opt,name=verify_certificate,json=verifyCertificate,def=1" json:"verify_certificate,omitempty"`
ThreadConfig *Configuration_ThreadConfig `` /* 151-byte string literal not displayed */
ThreadPoolSize *uint32 `protobuf:"varint,27,opt,name=thread_pool_size,json=threadPoolSize,def=64" json:"thread_pool_size,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Configuration) Descriptor ¶
func (*Configuration) Descriptor() ([]byte, []int)
func (*Configuration) GetAdditionalMetricDims ¶
func (m *Configuration) GetAdditionalMetricDims() []*AdditionalDimension
func (*Configuration) GetAggregationEnabled ¶
func (m *Configuration) GetAggregationEnabled() bool
func (*Configuration) GetAggregationMaxCount ¶
func (m *Configuration) GetAggregationMaxCount() uint64
func (*Configuration) GetAggregationMaxSize ¶
func (m *Configuration) GetAggregationMaxSize() uint64
func (*Configuration) GetCloudwatchEndpoint ¶
func (m *Configuration) GetCloudwatchEndpoint() string
func (*Configuration) GetCloudwatchPort ¶
func (m *Configuration) GetCloudwatchPort() uint64
func (*Configuration) GetCollectionMaxCount ¶
func (m *Configuration) GetCollectionMaxCount() uint64
func (*Configuration) GetCollectionMaxSize ¶
func (m *Configuration) GetCollectionMaxSize() uint64
func (*Configuration) GetConnectTimeout ¶
func (m *Configuration) GetConnectTimeout() uint64
func (*Configuration) GetEnableCoreDumps ¶
func (m *Configuration) GetEnableCoreDumps() bool
func (*Configuration) GetFailIfThrottled ¶
func (m *Configuration) GetFailIfThrottled() bool
func (*Configuration) GetKinesisEndpoint ¶
func (m *Configuration) GetKinesisEndpoint() string
func (*Configuration) GetKinesisPort ¶
func (m *Configuration) GetKinesisPort() uint64
func (*Configuration) GetLogLevel ¶
func (m *Configuration) GetLogLevel() string
func (*Configuration) GetMaxConnections ¶
func (m *Configuration) GetMaxConnections() uint64
func (*Configuration) GetMetricsGranularity ¶
func (m *Configuration) GetMetricsGranularity() string
func (*Configuration) GetMetricsLevel ¶
func (m *Configuration) GetMetricsLevel() string
func (*Configuration) GetMetricsNamespace ¶
func (m *Configuration) GetMetricsNamespace() string
func (*Configuration) GetMetricsUploadDelay ¶
func (m *Configuration) GetMetricsUploadDelay() uint64
func (*Configuration) GetMinConnections ¶
func (m *Configuration) GetMinConnections() uint64
func (*Configuration) GetRateLimit ¶
func (m *Configuration) GetRateLimit() uint64
func (*Configuration) GetRecordMaxBufferedTime ¶
func (m *Configuration) GetRecordMaxBufferedTime() uint64
func (*Configuration) GetRecordTtl ¶
func (m *Configuration) GetRecordTtl() uint64
func (*Configuration) GetRegion ¶
func (m *Configuration) GetRegion() string
func (*Configuration) GetRequestTimeout ¶
func (m *Configuration) GetRequestTimeout() uint64
func (*Configuration) GetThreadConfig ¶
func (m *Configuration) GetThreadConfig() Configuration_ThreadConfig
func (*Configuration) GetThreadPoolSize ¶
func (m *Configuration) GetThreadPoolSize() uint32
func (*Configuration) GetVerifyCertificate ¶
func (m *Configuration) GetVerifyCertificate() bool
func (*Configuration) ProtoMessage ¶
func (*Configuration) ProtoMessage()
func (*Configuration) Reset ¶
func (m *Configuration) Reset()
func (*Configuration) String ¶
func (m *Configuration) String() string
func (*Configuration) XXX_DiscardUnknown ¶
func (m *Configuration) XXX_DiscardUnknown()
func (*Configuration) XXX_Marshal ¶
func (m *Configuration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*Configuration) XXX_Merge ¶
func (dst *Configuration) XXX_Merge(src proto.Message)
func (*Configuration) XXX_Size ¶
func (m *Configuration) XXX_Size() int
func (*Configuration) XXX_Unmarshal ¶
func (m *Configuration) XXX_Unmarshal(b []byte) error
type Configuration_ThreadConfig ¶
type Configuration_ThreadConfig int32
const ( Configuration_PER_REQUEST Configuration_ThreadConfig = 0 Configuration_POOLED Configuration_ThreadConfig = 1 )
const Default_Configuration_ThreadConfig Configuration_ThreadConfig = Configuration_PER_REQUEST
func (Configuration_ThreadConfig) Enum ¶
func (x Configuration_ThreadConfig) Enum() *Configuration_ThreadConfig
func (Configuration_ThreadConfig) EnumDescriptor ¶
func (Configuration_ThreadConfig) EnumDescriptor() ([]byte, []int)
func (Configuration_ThreadConfig) String ¶
func (x Configuration_ThreadConfig) String() string
func (*Configuration_ThreadConfig) UnmarshalJSON ¶
func (x *Configuration_ThreadConfig) UnmarshalJSON(data []byte) error
type Credentials ¶
type Credentials struct {
Akid *string `protobuf:"bytes,1,req,name=akid" json:"akid,omitempty"`
SecretKey *string `protobuf:"bytes,2,req,name=secret_key,json=secretKey" json:"secret_key,omitempty"`
Token *string `protobuf:"bytes,3,opt,name=token" json:"token,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Credentials) Descriptor ¶
func (*Credentials) Descriptor() ([]byte, []int)
func (*Credentials) GetAkid ¶
func (m *Credentials) GetAkid() string
func (*Credentials) GetSecretKey ¶
func (m *Credentials) GetSecretKey() string
func (*Credentials) GetToken ¶
func (m *Credentials) GetToken() string
func (*Credentials) ProtoMessage ¶
func (*Credentials) ProtoMessage()
func (*Credentials) Reset ¶
func (m *Credentials) Reset()
func (*Credentials) String ¶
func (m *Credentials) String() string
func (*Credentials) XXX_DiscardUnknown ¶
func (m *Credentials) XXX_DiscardUnknown()
func (*Credentials) XXX_Marshal ¶
func (m *Credentials) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*Credentials) XXX_Merge ¶
func (dst *Credentials) XXX_Merge(src proto.Message)
func (*Credentials) XXX_Size ¶
func (m *Credentials) XXX_Size() int
func (*Credentials) XXX_Unmarshal ¶
func (m *Credentials) XXX_Unmarshal(b []byte) error
type Dimension ¶
type Dimension struct {
Key *string `protobuf:"bytes,1,req,name=key" json:"key,omitempty"`
Value *string `protobuf:"bytes,2,req,name=value" json:"value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Dimension) Descriptor ¶
func (*Dimension) ProtoMessage ¶
func (*Dimension) ProtoMessage()
func (*Dimension) XXX_DiscardUnknown ¶
func (m *Dimension) XXX_DiscardUnknown()
func (*Dimension) XXX_Marshal ¶
func (*Dimension) XXX_Unmarshal ¶
type Flush ¶
type Flush struct {
StreamName *string `protobuf:"bytes,1,opt,name=stream_name,json=streamName" json:"stream_name,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Flush) Descriptor ¶
func (*Flush) GetStreamName ¶
func (*Flush) ProtoMessage ¶
func (*Flush) ProtoMessage()
func (*Flush) XXX_DiscardUnknown ¶
func (m *Flush) XXX_DiscardUnknown()
func (*Flush) XXX_Marshal ¶
func (*Flush) XXX_Unmarshal ¶
type Message ¶
type Message struct {
Id *uint64 `protobuf:"varint,1,req,name=id" json:"id,omitempty"`
SourceId *uint64 `protobuf:"varint,2,opt,name=source_id,json=sourceId" json:"source_id,omitempty"`
// Types that are valid to be assigned to ActualMessage:
// *Message_PutRecord
// *Message_Flush
// *Message_PutRecordResult
// *Message_Configuration
// *Message_MetricsRequest
// *Message_MetricsResponse
// *Message_SetCredentials
ActualMessage isMessage_ActualMessage `protobuf_oneof:"actual_message"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Message) Descriptor ¶
func (*Message) GetActualMessage ¶
func (m *Message) GetActualMessage() isMessage_ActualMessage
func (*Message) GetConfiguration ¶
func (m *Message) GetConfiguration() *Configuration
func (*Message) GetMetricsRequest ¶
func (m *Message) GetMetricsRequest() *MetricsRequest
func (*Message) GetMetricsResponse ¶
func (m *Message) GetMetricsResponse() *MetricsResponse
func (*Message) GetPutRecord ¶
func (*Message) GetPutRecordResult ¶
func (m *Message) GetPutRecordResult() *PutRecordResult
func (*Message) GetSetCredentials ¶
func (m *Message) GetSetCredentials() *SetCredentials
func (*Message) GetSourceId ¶
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) XXX_DiscardUnknown ¶
func (m *Message) XXX_DiscardUnknown()
func (*Message) XXX_Marshal ¶
func (*Message) XXX_OneofFuncs ¶
func (*Message) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{})
XXX_OneofFuncs is for the internal use of the proto package.
func (*Message) XXX_Unmarshal ¶
type Message_Configuration ¶
type Message_Configuration struct {
Configuration *Configuration `protobuf:"bytes,6,opt,name=configuration,oneof"`
}
type Message_Flush ¶
type Message_Flush struct {
Flush *Flush `protobuf:"bytes,4,opt,name=flush,oneof"`
}
type Message_MetricsRequest ¶
type Message_MetricsRequest struct {
MetricsRequest *MetricsRequest `protobuf:"bytes,7,opt,name=metrics_request,json=metricsRequest,oneof"`
}
type Message_MetricsResponse ¶
type Message_MetricsResponse struct {
MetricsResponse *MetricsResponse `protobuf:"bytes,8,opt,name=metrics_response,json=metricsResponse,oneof"`
}
type Message_PutRecord ¶
type Message_PutRecord struct {
PutRecord *PutRecord `protobuf:"bytes,3,opt,name=put_record,json=putRecord,oneof"`
}
type Message_PutRecordResult ¶
type Message_PutRecordResult struct {
PutRecordResult *PutRecordResult `protobuf:"bytes,5,opt,name=put_record_result,json=putRecordResult,oneof"`
}
type Message_SetCredentials ¶
type Message_SetCredentials struct {
SetCredentials *SetCredentials `protobuf:"bytes,9,opt,name=set_credentials,json=setCredentials,oneof"`
}
type Metric ¶
type Metric struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
Dimensions []*Dimension `protobuf:"bytes,2,rep,name=dimensions" json:"dimensions,omitempty"`
Stats *Stats `protobuf:"bytes,3,req,name=stats" json:"stats,omitempty"`
Seconds *uint64 `protobuf:"varint,4,req,name=seconds" json:"seconds,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Metric) Descriptor ¶
func (*Metric) GetDimensions ¶
func (*Metric) GetSeconds ¶
func (*Metric) ProtoMessage ¶
func (*Metric) ProtoMessage()
func (*Metric) XXX_DiscardUnknown ¶
func (m *Metric) XXX_DiscardUnknown()
func (*Metric) XXX_Marshal ¶
func (*Metric) XXX_Unmarshal ¶
type MetricsRequest ¶
type MetricsRequest struct {
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Seconds *uint64 `protobuf:"varint,2,opt,name=seconds" json:"seconds,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*MetricsRequest) Descriptor ¶
func (*MetricsRequest) Descriptor() ([]byte, []int)
func (*MetricsRequest) GetName ¶
func (m *MetricsRequest) GetName() string
func (*MetricsRequest) GetSeconds ¶
func (m *MetricsRequest) GetSeconds() uint64
func (*MetricsRequest) ProtoMessage ¶
func (*MetricsRequest) ProtoMessage()
func (*MetricsRequest) Reset ¶
func (m *MetricsRequest) Reset()
func (*MetricsRequest) String ¶
func (m *MetricsRequest) String() string
func (*MetricsRequest) XXX_DiscardUnknown ¶
func (m *MetricsRequest) XXX_DiscardUnknown()
func (*MetricsRequest) XXX_Marshal ¶
func (m *MetricsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*MetricsRequest) XXX_Merge ¶
func (dst *MetricsRequest) XXX_Merge(src proto.Message)
func (*MetricsRequest) XXX_Size ¶
func (m *MetricsRequest) XXX_Size() int
func (*MetricsRequest) XXX_Unmarshal ¶
func (m *MetricsRequest) XXX_Unmarshal(b []byte) error
type MetricsResponse ¶
type MetricsResponse struct {
Metrics []*Metric `protobuf:"bytes,1,rep,name=metrics" json:"metrics,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*MetricsResponse) Descriptor ¶
func (*MetricsResponse) Descriptor() ([]byte, []int)
func (*MetricsResponse) GetMetrics ¶
func (m *MetricsResponse) GetMetrics() []*Metric
func (*MetricsResponse) ProtoMessage ¶
func (*MetricsResponse) ProtoMessage()
func (*MetricsResponse) Reset ¶
func (m *MetricsResponse) Reset()
func (*MetricsResponse) String ¶
func (m *MetricsResponse) String() string
func (*MetricsResponse) XXX_DiscardUnknown ¶
func (m *MetricsResponse) XXX_DiscardUnknown()
func (*MetricsResponse) XXX_Marshal ¶
func (m *MetricsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*MetricsResponse) XXX_Merge ¶
func (dst *MetricsResponse) XXX_Merge(src proto.Message)
func (*MetricsResponse) XXX_Size ¶
func (m *MetricsResponse) XXX_Size() int
func (*MetricsResponse) XXX_Unmarshal ¶
func (m *MetricsResponse) XXX_Unmarshal(b []byte) error
type PutRecord ¶
type PutRecord struct {
StreamName *string `protobuf:"bytes,1,req,name=stream_name,json=streamName" json:"stream_name,omitempty"`
PartitionKey *string `protobuf:"bytes,2,req,name=partition_key,json=partitionKey" json:"partition_key,omitempty"`
ExplicitHashKey *string `protobuf:"bytes,3,opt,name=explicit_hash_key,json=explicitHashKey" json:"explicit_hash_key,omitempty"`
Data []byte `protobuf:"bytes,4,req,name=data" json:"data,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*PutRecord) Descriptor ¶
func (*PutRecord) GetExplicitHashKey ¶
func (*PutRecord) GetPartitionKey ¶
func (*PutRecord) GetStreamName ¶
func (*PutRecord) ProtoMessage ¶
func (*PutRecord) ProtoMessage()
func (*PutRecord) XXX_DiscardUnknown ¶
func (m *PutRecord) XXX_DiscardUnknown()
func (*PutRecord) XXX_Marshal ¶
func (*PutRecord) XXX_Unmarshal ¶
type PutRecordResult ¶
type PutRecordResult struct {
Attempts []*Attempt `protobuf:"bytes,1,rep,name=attempts" json:"attempts,omitempty"`
Success *bool `protobuf:"varint,2,req,name=success" json:"success,omitempty"`
ShardId *string `protobuf:"bytes,3,opt,name=shard_id,json=shardId" json:"shard_id,omitempty"`
SequenceNumber *string `protobuf:"bytes,4,opt,name=sequence_number,json=sequenceNumber" json:"sequence_number,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*PutRecordResult) Descriptor ¶
func (*PutRecordResult) Descriptor() ([]byte, []int)
func (*PutRecordResult) GetAttempts ¶
func (m *PutRecordResult) GetAttempts() []*Attempt
func (*PutRecordResult) GetSequenceNumber ¶
func (m *PutRecordResult) GetSequenceNumber() string
func (*PutRecordResult) GetShardId ¶
func (m *PutRecordResult) GetShardId() string
func (*PutRecordResult) GetSuccess ¶
func (m *PutRecordResult) GetSuccess() bool
func (*PutRecordResult) ProtoMessage ¶
func (*PutRecordResult) ProtoMessage()
func (*PutRecordResult) Reset ¶
func (m *PutRecordResult) Reset()
func (*PutRecordResult) String ¶
func (m *PutRecordResult) String() string
func (*PutRecordResult) XXX_DiscardUnknown ¶
func (m *PutRecordResult) XXX_DiscardUnknown()
func (*PutRecordResult) XXX_Marshal ¶
func (m *PutRecordResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*PutRecordResult) XXX_Merge ¶
func (dst *PutRecordResult) XXX_Merge(src proto.Message)
func (*PutRecordResult) XXX_Size ¶
func (m *PutRecordResult) XXX_Size() int
func (*PutRecordResult) XXX_Unmarshal ¶
func (m *PutRecordResult) XXX_Unmarshal(b []byte) error
type Record ¶
type Record struct {
PartitionKeyIndex *uint64 `protobuf:"varint,1,req,name=partition_key_index,json=partitionKeyIndex" json:"partition_key_index,omitempty"`
ExplicitHashKeyIndex *uint64 `protobuf:"varint,2,opt,name=explicit_hash_key_index,json=explicitHashKeyIndex" json:"explicit_hash_key_index,omitempty"`
Data []byte `protobuf:"bytes,3,req,name=data" json:"data,omitempty"`
Tags []*Tag `protobuf:"bytes,4,rep,name=tags" json:"tags,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Record) Descriptor ¶
func (*Record) GetExplicitHashKeyIndex ¶
func (*Record) GetPartitionKeyIndex ¶
func (*Record) ProtoMessage ¶
func (*Record) ProtoMessage()
func (*Record) XXX_DiscardUnknown ¶
func (m *Record) XXX_DiscardUnknown()
func (*Record) XXX_Marshal ¶
func (*Record) XXX_Unmarshal ¶
type SetCredentials ¶
type SetCredentials struct {
ForMetrics *bool `protobuf:"varint,1,opt,name=for_metrics,json=forMetrics" json:"for_metrics,omitempty"`
Credentials *Credentials `protobuf:"bytes,2,req,name=credentials" json:"credentials,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*SetCredentials) Descriptor ¶
func (*SetCredentials) Descriptor() ([]byte, []int)
func (*SetCredentials) GetCredentials ¶
func (m *SetCredentials) GetCredentials() *Credentials
func (*SetCredentials) GetForMetrics ¶
func (m *SetCredentials) GetForMetrics() bool
func (*SetCredentials) ProtoMessage ¶
func (*SetCredentials) ProtoMessage()
func (*SetCredentials) Reset ¶
func (m *SetCredentials) Reset()
func (*SetCredentials) String ¶
func (m *SetCredentials) String() string
func (*SetCredentials) XXX_DiscardUnknown ¶
func (m *SetCredentials) XXX_DiscardUnknown()
func (*SetCredentials) XXX_Marshal ¶
func (m *SetCredentials) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*SetCredentials) XXX_Merge ¶
func (dst *SetCredentials) XXX_Merge(src proto.Message)
func (*SetCredentials) XXX_Size ¶
func (m *SetCredentials) XXX_Size() int
func (*SetCredentials) XXX_Unmarshal ¶
func (m *SetCredentials) XXX_Unmarshal(b []byte) error
type Stats ¶
type Stats struct {
Count *float64 `protobuf:"fixed64,1,req,name=count" json:"count,omitempty"`
Sum *float64 `protobuf:"fixed64,2,req,name=sum" json:"sum,omitempty"`
Mean *float64 `protobuf:"fixed64,3,req,name=mean" json:"mean,omitempty"`
Min *float64 `protobuf:"fixed64,4,req,name=min" json:"min,omitempty"`
Max *float64 `protobuf:"fixed64,5,req,name=max" json:"max,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Stats) Descriptor ¶
func (*Stats) ProtoMessage ¶
func (*Stats) ProtoMessage()
func (*Stats) XXX_DiscardUnknown ¶
func (m *Stats) XXX_DiscardUnknown()
func (*Stats) XXX_Marshal ¶
func (*Stats) XXX_Unmarshal ¶
type Tag ¶
type Tag struct {
Key *string `protobuf:"bytes,1,req,name=key" json:"key,omitempty"`
Value *string `protobuf:"bytes,2,opt,name=value" json:"value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Tag) Descriptor ¶
func (*Tag) ProtoMessage ¶
func (*Tag) ProtoMessage()
func (*Tag) XXX_DiscardUnknown ¶
func (m *Tag) XXX_DiscardUnknown()
func (*Tag) XXX_Unmarshal ¶
Click to show internal directories.
Click to hide internal directories.